@@ -36,7 +36,7 @@ class Provider(AddressProvider):
         'Bersenbrück', 'Biedenkopf', 'Bischofswerda', 'Bitterfeld', 'Bogen',
         'Borken', 'Borna', 'Brand', 'Brandenburg', 'Bremen', 'Bremervörde',
         'Brilon', 'Bruchsal', 'Burg', 'Burgdorf', 'Burglengenfeld',
-        'Böblingen', 'Büsingenm Hochrhein', 'Bützow', 'Calau', 'Calw', 'Celle',
+        'Böblingen', 'Büsingen am Hochrhein', 'Bützow', 'Calau', 'Calw', 'Celle',
         'Chemnitz', 'Cloppenburg', 'Coburg', 'Cottbus', 'Crailsheim',
         'Cuxhaven', 'Dachau', 'Darmstadt', 'Deggendorf', 'Delitzsch', 'Demmin',
         'Dessau', 'Dieburg', 'Diepholz', 'Dinkelsbühl', 'Dinslaken',
@@ -72,19 +72,19 @@ class Provider(AddressProvider):
         'Mallersdorf', 'Marienberg', 'Marktheidenfeld', 'Mayen', 'Meiningen',
         'Meißen', 'Melle', 'Mellrichstadt', 'Melsungen', 'Meppen', 'Merseburg',
         'Mettmann', 'Miesbach', 'Miltenberg', 'Mittweida', 'Moers', 'Monschau',
-        'Mühldorfm Inn', 'Mühlhausen', 'München', 'Nabburg', 'Naila', 'Nauen',
+        'Mühldorf am Inn', 'Mühlhausen', 'München', 'Nabburg', 'Naila', 'Nauen',
         'Neu-Ulm', 'Neubrandenburg', 'Neunburg vorm Wald', 'Neuruppin',
-        'Neuss', 'Neustadtm Rübenberge', 'Neustadtner Waldnaab', 'Neustrelitz',
+        'Neuss', 'Neustadt am Rübenberge', 'Neustadtner Waldnaab', 'Neustrelitz',
         'Niesky', 'Norden', 'Nordhausen', 'Northeim', 'Nördlingen',
         'Nürtingen', 'Oberviechtach', 'Ochsenfurt', 'Olpe', 'Oranienburg',
-        'Oschatz', 'Osterburg', 'Osterodem Harz', 'Paderborn', 'Parchim',
+        'Oschatz', 'Osterburg', 'Osterode am Harz', 'Paderborn', 'Parchim',
         'Parsberg', 'Pasewalk', 'Passau', 'Pegnitz', 'Peine', 'Perleberg',
-        'Pfaffenhofenner Ilm', 'Pinneberg', 'Pirmasens', 'Plauen', 'Potsdam',
+        'Pfaffenhofen an der Ilm', 'Pinneberg', 'Pirmasens', 'Plauen', 'Potsdam',
         'Prenzlau', 'Pritzwalk', 'Pößneck', 'Quedlinburg', 'Querfurt',
         'Rastatt', 'Rathenow', 'Ravensburg', 'Recklinghausen', 'Regen',
         'Regensburg', 'Rehau', 'Reutlingen', 'Ribnitz-Damgarten', 'Riesa',
         'Rochlitz', 'Rockenhausen', 'Roding', 'Rosenheim', 'Rostock', 'Roth',
-        'Rothenburg oberauber', 'Rottweil', 'Rudolstadt', 'Saarbrücken',
+        'Rothenburg ob der Tauber', 'Rottweil', 'Rudolstadt', 'Saarbrücken',
         'Saarlouis', 'Sangerhausen', 'Sankt Goar', 'Sankt Goarshausen',
         'Saulgau', 'Scheinfeld', 'Schleiz', 'Schlüchtern', 'Schmölln',
         'Schongau', 'Schrobenhausen', 'Schwabmünchen', 'Schwandorf',
